<?php

namespace App\Http\Controllers\Settings;

use Illuminate\Http\Request;
use App\Http\Controllers\Controller;
use Illuminate\Support\Facades\Http;
use App\DataTables\Settings\IncrementDataTable;

class IncrementController extends Controller
{
    private function fetch_employees(): array
    {
        $token = session('bearer_token');
        $apiBaseUrl = env('API_BASE_URL');
        
        $response = Http::withToken($token)->get("{$apiBaseUrl}/employees");
    
        if ($response->successful()) {
            // Fetch the employee data including related user name
            $employees = $response->json()['employees'] ?? [];
            
            // Extract only the employee ID and the associated user name
            $employees = array_map(function ($employee) {
                return [
                    'id' => $employee['id'], // Employee ID
                    'name' => $employee['user_profile']['user']['name'] ?? null, // Associated User's Name
                ];
            }, $employees);
    
            return $employees;
        }
    
        return [];
    }
    
    public function increment_list(IncrementDataTable $dataTable)
    {
        $employees = $this->fetch_employees();
        return $dataTable->render('admin.settings.increment',compact('employees'));
    }
    public function add_increment_form(Request $request)
    {
       
        try {
            $token = session('bearer_token');
            $apiBaseUrl = env('API_BASE_URL');
            $org_id = session('org_id');
            $response = Http::withToken($token)->post("{$apiBaseUrl}/increments/store", [
                'employee_id' => $request->employee_id,
                'amount' => $request->amount,
                'date' => $request->date,
                'reason' => $request->reason,
                'status' => 'active',
                'org_id' => $org_id
            ]);
          
    
            if ($response->successful()) {
                return response()->json(['success' => true, 'message' => 'Increment added successfully']);
            } else {
                $error = $response->json();
                return response()->json([
                    'success' => false,
                    'message' => $error['message'] ?? 'Failed to add Increment.'
                ], $response->status());
            }
        } catch (\Exception $e) {
            return response()->json(['success' => false, 'message' => 'Something went wrong: ' . $e->getMessage()], 500);
        }
    }
    public function update_Increment_form(Request $request, $id)
    {
        try {
            // Get the token from session and set the base API URL
            $token = session('bearer_token');
            $apiBaseUrl = env('API_BASE_URL');
    
            // Send a PUT request to update the education
            $response = Http::withToken($token)->put("{$apiBaseUrl}/increments/update/{$id}", [
                'employee_id' => $request->employee_id,
                'amount' => $request->amount,
                'date' => $request->date,
                'reason' => $request->reason,
                'status' => 'active'
            ]);
    
            // Check if the response is successful
            if ($response->successful()) {
                return response()->json(['success' => true, 'message' => 'Increment updated successfully']);
            } else {
                // If the response contains an error, extract the error message
                $error = $response->json();
                return response()->json([
                    'success' => false,
                    'message' => $error['message'] ?? 'Failed to update Increment.'
                ], $response->status());
            }
        } catch (\Exception $e) {
            // Handle general exceptions
            return response()->json(['success' => false, 'message' => 'Something went wrong: ' . $e->getMessage()], 500);
        }
    }
    public function update_increment_status(Request $request)
    {
        try {
            // Validate incoming request
            $request->validate([
                'id' => 'required|integer', // Ensure 'id' is present and is an integer
            ]);
    
            // Get the bearer token from the session and the base API URL from environment config
            $token = session('bearer_token');
            $apiBaseUrl = env('API_BASE_URL');
            
            // Prepare the payload with table and ID
            $payload = [
                'table' => 'increments',  // The table name is hardcoded as 'organizations'
                'id' => $request->id  // ID is passed from the request
            ];
            
            // Send a POST request to the external API to update the status
            $response = Http::withToken($token)->post("{$apiBaseUrl}/update/status", $payload);
    
            // Check if the response was successful
            if ($response->successful()) {
                return response()->json([
                    'success' => true,
                    'message' => 'Status updated successfully'
                ]);
            } else {
                // If the request fails, return the error message from the API response
                $error = $response->json();
                return response()->json([
                    'success' => false,
                    'message' => $error['message'] ?? 'Failed to update status'
                ], $response->status());
            }
        } catch (\Exception $e) {
            // Catch any exceptions and return a 500 response with the error message
            return response()->json([
                'success' => false,
                'message' => 'Something went wrong: ' . $e->getMessage()
            ], 500);
        }
    }
    
    
    public function delete_increment($id)
    {
        $token = session('bearer_token');
        $apiBaseUrl = env('API_BASE_URL');
        $response = Http::withToken($token)->delete("{$apiBaseUrl}/increments/{$id}");

        if ($response->successful()) {
            return response()->json(['success' => true, 'message' => 'Increment deleted successfully']);
        } else {
            // Ensure the error message is correctly fetched from the API response
            $error = $response->json();
            return response()->json([
                'success' => false,
                'message' => $error['message'] ?? 'Unable to delete Increment'
            ], $response->status());
        }
    }

    public function get_increment($id)
    {
        try {
            $token = session('bearer_token');
            $apiBaseUrl = env('API_BASE_URL');
            // Make the GET request to the external API
            $response = Http::withToken($token)->get("{$apiBaseUrl}/increments/get/{$id}");
            
            if ($response->successful()) {
                // Get the increment data (assuming only one increment is retrieved for a given id)
                $incrementData = $response->json()['increment'];
                return response()->json($incrementData);
            } else {
                return response()->json(['status' => 404, 'message' => 'Increment not found.'], 404);
            }
        } catch (\Exception $e) {
            return response()->json(['message' => 'An error occurred: ' . $e->getMessage()], 500);
        }
    }
    
}
